# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
ad = 63041
address_book = 62137
address_card = 62139
adjust = 61506
air_freshener = 62928
align_center = 61495
align_justify = 61497
align_left = 61494
align_right = 61496
allergies = 62561
ambulance = 61689
american_sign_language_interpreting = 62115
anchor = 61757
angle_double_down = 61699
angle_double_left = 61696
angle_double_right = 61697
angle_double_up = 61698
angle_down = 61703
angle_left = 61700
angle_right = 61701
angle_up = 61702
angry = 62806
ankh = 63044
apple_alt = 62929
archive = 61831
archway = 62807
arrow_alt_circle_down = 62296
arrow_alt_circle_left = 62297
arrow_alt_circle_right = 62298
arrow_alt_circle_up = 62299
arrow_circle_down = 61611
arrow_circle_left = 61608
arrow_circle_right = 61609
arrow_circle_up = 61610
arrow_down = 61539
arrow_left = 61536
arrow_right = 61537
arrow_up = 61538
arrows_alt = 61618
arrows_alt_h = 62263
arrows_alt_v = 62264
assistive_listening_systems = 62114
asterisk = 61545
at = 61946
atlas = 62808
atom = 62930
audio_description = 62110
award = 62809
baby = 63356
baby_carriage = 63357
backspace = 62810
backward = 61514
bacon = 63461
bacteria = 57433
bacterium = 57434
bahai = 63078
balance_scale = 62030
balance_scale_left = 62741
balance_scale_right = 62742
ban = 61534
band_aid = 62562
barcode = 61482
bars = 61641
baseball_ball = 62515
basketball_ball = 62516
bath = 62157
battery_empty = 62020
battery_full = 62016
battery_half = 62018
battery_quarter = 62019
battery_three_quarters = 62017
bed = 62006
beer = 61692
bell = 61683
bell_slash = 61942
bezier_curve = 62811
bible = 63047
bicycle = 61958
biking = 63562
binoculars = 61925
biohazard = 63360
birthday_cake = 61949
blender = 62743
blender_phone = 63158
blind = 62109
blog = 63361
bold = 61490
bolt = 61671
bomb = 61922
bone = 62935
bong = 62812
book = 61485
book_dead = 63159
book_medical = 63462
book_open = 62744
book_reader = 62938
bookmark = 61486
border_all = 63564
border_none = 63568
border_style = 63571
bowling_ball = 62518
box = 62566
box_open = 62622
box_tissue = 57435
boxes = 62568
braille = 62113
brain = 62940
bread_slice = 63468
briefcase = 61617
briefcase_medical = 62569
broadcast_tower = 62745
broom = 62746
brush = 62813
bug = 61832
building = 61869
bullhorn = 61601
bullseye = 61760
burn = 62570
bus = 61959
bus_alt = 62814
business_time = 63050
calculator = 61932
calendar = 61747
calendar_alt = 61555
calendar_check = 62068
calendar_day = 63363
calendar_minus = 62066
calendar_plus = 62065
calendar_times = 62067
calendar_week = 63364
camera = 61488
camera_retro = 61571
campground = 63163
candy_cane = 63366
cannabis = 62815
capsules = 62571
car = 61881
car_alt = 62942
car_battery = 62943
car_crash = 62945
car_side = 62948
caravan = 63743
caret_down = 61655
caret_left = 61657
caret_right = 61658
caret_square_down = 61776
caret_square_left = 61841
caret_square_right = 61778
caret_square_up = 61777
caret_up = 61656
carrot = 63367
cart_arrow_down = 61976
cart_plus = 61975
cash_register = 63368
cat = 63166
certificate = 61603
chair = 63168
chalkboard = 62747
chalkboard_teacher = 62748
charging_station = 62951
chart_area = 61950
chart_bar = 61568
chart_line = 61953
chart_pie = 61952
check = 61452
check_circle = 61528
check_double = 62816
check_square = 61770
cheese = 63471
chess = 62521
chess_bishop = 62522
chess_board = 62524
chess_king = 62527
chess_knight = 62529
chess_pawn = 62531
chess_queen = 62533
chess_rook = 62535
chevron_circle_down = 61754
chevron_circle_left = 61751
chevron_circle_right = 61752
chevron_circle_up = 61753
chevron_down = 61560
chevron_left = 61523
chevron_right = 61524
chevron_up = 61559
child = 61870
church = 62749
circle = 61713
circle_notch = 61902
city = 63055
clinic_medical = 63474
clipboard = 62248
clipboard_check = 62572
clipboard_list = 62573
clock = 61463
clone = 62029
closed_captioning = 61962
cloud = 61634
cloud_download_alt = 62337
cloud_meatball = 63291
cloud_moon = 63171
cloud_moon_rain = 63292
cloud_rain = 63293
cloud_showers_heavy = 63296
cloud_sun = 63172
cloud_sun_rain = 63299
cloud_upload_alt = 62338
cocktail = 62817
code = 61729
code_branch = 61734
coffee = 61684
cog = 61459
cogs = 61573
coins = 62750
columns = 61659
comment = 61557
comment_alt = 62074
comment_dollar = 63057
comment_dots = 62637
comment_medical = 63477
comment_slash = 62643
comments = 61574
comments_dollar = 63059
compact_disc = 62751
compass = 61774
compress = 61542
compress_alt = 62498
compress_arrows_alt = 63372
concierge_bell = 62818
cookie = 62819
cookie_bite = 62820
copy = 61637
copyright = 61945
couch = 62648
credit_card = 61597
crop = 61733
crop_alt = 62821
cross = 63060
crosshairs = 61531
crow = 62752
crown = 62753
crutch = 63479
cube = 61874
cubes = 61875
cut = 61636
database = 61888
deaf = 62116
democrat = 63303
desktop = 61704
dharmachakra = 63061
diagnoses = 62576
dice = 62754
dice_d20 = 63183
dice_d6 = 63185
dice_five = 62755
dice_four = 62756
dice_one = 62757
dice_six = 62758
dice_three = 62759
dice_two = 62760
digital_tachograph = 62822
directions = 62955
disease = 63482
divide = 62761
dizzy = 62823
dna = 62577
dog = 63187
dollar_sign = 61781
dolly = 62578
dolly_flatbed = 62580
donate = 62649
door_closed = 62762
door_open = 62763
dot_circle = 61842
dove = 62650
download = 61465
drafting_compass = 62824
dragon = 63189
draw_polygon = 62958
drum = 62825
drum_steelpan = 62826
drumstick_bite = 63191
dumbbell = 62539
dumpster = 63379
dumpster_fire = 63380
dungeon = 63193
edit = 61508
egg = 63483
eject = 61522
ellipsis_h = 61761
ellipsis_v = 61762
envelope = 61664
envelope_open = 62134
envelope_open_text = 63064
envelope_square = 61849
equals = 62764
eraser = 61741
ethernet = 63382
euro_sign = 61779
exchange_alt = 62306
exclamation = 61738
exclamation_circle = 61546
exclamation_triangle = 61553
expand = 61541
expand_alt = 62500
expand_arrows_alt = 62238
external_link_alt = 62301
external_link_square_alt = 62304
eye = 61550
eye_dropper = 61947
eye_slash = 61552
fan = 63587
fast_backward = 61513
fast_forward = 61520
faucet = 57349
fax = 61868
feather = 62765
feather_alt = 62827
female = 61826
fighter_jet = 61691
file = 61787
file_alt = 61788
file_archive = 61894
file_audio = 61895
file_code = 61897
file_contract = 62828
file_csv = 63197
file_download = 62829
file_excel = 61891
file_export = 62830
file_image = 61893
file_import = 62831
file_invoice = 62832
file_invoice_dollar = 62833
file_medical = 62583
file_medical_alt = 62584
file_pdf = 61889
file_powerpoint = 61892
file_prescription = 62834
file_signature = 62835
file_upload = 62836
file_video = 61896
file_word = 61890
fill = 62837
fill_drip = 62838
film = 61448
filter = 61616
fingerprint = 62839
fire = 61549
fire_alt = 63460
fire_extinguisher = 61748
first_aid = 62585
fish = 62840
fist_raised = 63198
flag = 61476
flag_checkered = 61726
flag_usa = 63309
flask = 61635
flushed = 62841
folder = 61563
folder_minus = 63069
folder_open = 61564
folder_plus = 63070
font = 61489
font_awesome_logo_full = 62694
football_ball = 62542
forward = 61518
frog = 62766
frown = 61721
frown_open = 62842
funnel_dollar = 63074
futbol = 61923
gamepad = 61723
gas_pump = 62767
gavel = 61667
gem = 62373
genderless = 61997
ghost = 63202
gift = 61547
gifts = 63388
glass_cheers = 63391
glass_martini = 61440
glass_martini_alt = 62843
glass_whiskey = 63392
glasses = 62768
globe = 61612
globe_africa = 62844
globe_americas = 62845
globe_asia = 62846
globe_europe = 63394
golf_ball = 62544
gopuram = 63076
graduation_cap = 61853
greater_than = 62769
greater_than_equal = 62770
grimace = 62847
grin = 62848
grin_alt = 62849
grin_beam = 62850
grin_beam_sweat = 62851
grin_hearts = 62852
grin_squint = 62853
grin_squint_tears = 62854
grin_stars = 62855
grin_tears = 62856
grin_tongue = 62857
grin_tongue_squint = 62858
grin_tongue_wink = 62859
grin_wink = 62860
grip_horizontal = 62861
grip_lines = 63396
grip_lines_vertical = 63397
grip_vertical = 62862
guitar = 63398
h_square = 61693
hamburger = 63493
hammer = 63203
hamsa = 63077
hand_holding = 62653
hand_holding_heart = 62654
hand_holding_medical = 57436
hand_holding_usd = 62656
hand_holding_water = 62657
hand_lizard = 62040
hand_middle_finger = 63494
hand_paper = 62038
hand_peace = 62043
hand_point_down = 61607
hand_point_left = 61605
hand_point_right = 61604
hand_point_up = 61606
hand_pointer = 62042
hand_rock = 62037
hand_scissors = 62039
hand_sparkles = 57437
hand_spock = 62041
hands = 62658
hands_helping = 62660
hands_wash = 57438
handshake = 62133
handshake_alt_slash = 57439
handshake_slash = 57440
hanukiah = 63206
hard_hat = 63495
hashtag = 62098
hat_cowboy = 63680
hat_cowboy_side = 63681
hat_wizard = 63208
hdd = 61600
head_side_cough = 57441
head_side_cough_slash = 57442
head_side_mask = 57443
head_side_virus = 57444
heading = 61916
headphones = 61477
headphones_alt = 62863
headset = 62864
heart = 61444
heart_broken = 63401
heartbeat = 61982
helicopter = 62771
highlighter = 62865
hiking = 63212
hippo = 63213
history = 61914
hockey_puck = 62547
holly_berry = 63402
home = 61461
horse = 63216
horse_head = 63403
hospital = 61688
hospital_alt = 62589
hospital_symbol = 62590
hospital_user = 63501
hot_tub = 62867
hotdog = 63503
hotel = 62868
hourglass = 62036
hourglass_end = 62035
hourglass_half = 62034
hourglass_start = 62033
house_damage = 63217
house_user = 57445
hryvnia = 63218
i_cursor = 62022
ice_cream = 63504
icicles = 63405
icons = 63597
id_badge = 62145
id_card = 62146
id_card_alt = 62591
igloo = 63406
image = 61502
images = 62210
inbox = 61468
indent = 61500
industry = 62069
infinity = 62772
info = 61737
info_circle = 61530
italic = 61491
jedi = 63081
joint = 62869
journal_whills = 63082
kaaba = 63083
key = 61572
keyboard = 61724
khanda = 63085
kiss = 62870
kiss_beam = 62871
kiss_wink_heart = 62872
kiwi_bird = 62773
landmark = 63087
language = 61867
laptop = 61705
laptop_code = 62972
laptop_house = 57446
laptop_medical = 63506
laugh = 62873
laugh_beam = 62874
laugh_squint = 62875
laugh_wink = 62876
layer_group = 62973
leaf = 61548
lemon = 61588
less_than = 62774
less_than_equal = 62775
level_down_alt = 62398
level_up_alt = 62399
life_ring = 61901
lightbulb = 61675
link = 61633
lira_sign = 61845
list = 61498
list_alt = 61474
list_ol = 61643
list_ul = 61642
location_arrow = 61732
lock = 61475
lock_open = 62401
long_arrow_alt_down = 62217
long_arrow_alt_left = 62218
long_arrow_alt_right = 62219
long_arrow_alt_up = 62220
low_vision = 62120
luggage_cart = 62877
lungs = 62980
lungs_virus = 57447
magic = 61648
magnet = 61558
mail_bulk = 63092
male = 61827
map = 62073
map_marked = 62879
map_marked_alt = 62880
map_marker = 61505
map_marker_alt = 62405
map_pin = 62070
map_signs = 62071
marker = 62881
mars = 61986
mars_double = 61991
mars_stroke = 61993
mars_stroke_h = 61995
mars_stroke_v = 61994
mask = 63226
medal = 62882
medkit = 61690
meh = 61722
meh_blank = 62884
meh_rolling_eyes = 62885
memory = 62776
menorah = 63094
mercury = 61987
meteor = 63315
microchip = 62171
microphone = 61744
microphone_alt = 62409
microphone_alt_slash = 62777
microphone_slash = 61745
microscope = 62992
minus = 61544
minus_circle = 61526
minus_square = 61766
mitten = 63413
mobile = 61707
mobile_alt = 62413
money_bill = 61654
money_bill_alt = 62417
money_bill_wave = 62778
money_bill_wave_alt = 62779
money_check = 62780
money_check_alt = 62781
monument = 62886
moon = 61830
mortar_pestle = 62887
mosque = 63096
motorcycle = 61980
mountain = 63228
mouse = 63692
mouse_pointer = 62021
mug_hot = 63414
music = 61441
network_wired = 63231
neuter = 61996
newspaper = 61930
not_equal = 62782
notes_medical = 62593
object_group = 62023
object_ungroup = 62024
oil_can = 62995
om = 63097
otter = 63232
outdent = 61499
pager = 63509
paint_brush = 61948
paint_roller = 62890
palette = 62783
pallet = 62594
paper_plane = 61912
paperclip = 61638
parachute_box = 62669
paragraph = 61917
parking = 62784
passport = 62891
pastafarianism = 63099
paste = 61674
pause = 61516
pause_circle = 62091
paw = 61872
peace = 63100
pen = 62212
pen_alt = 62213
pen_fancy = 62892
pen_nib = 62893
pen_square = 61771
pencil_alt = 62211
pencil_ruler = 62894
people_arrows = 57448
people_carry = 62670
pepper_hot = 63510
percent = 62101
percentage = 62785
person_booth = 63318
phone = 61589
phone_alt = 63609
phone_slash = 62429
phone_square = 61592
phone_square_alt = 63611
phone_volume = 62112
photo_video = 63612
piggy_bank = 62675
pills = 62596
pizza_slice = 63512
place_of_worship = 63103
plane = 61554
plane_arrival = 62895
plane_departure = 62896
plane_slash = 57449
play = 61515
play_circle = 61764
plug = 61926
plus = 61543
plus_circle = 61525
plus_square = 61694
podcast = 62158
poll = 63105
poll_h = 63106
poo = 62206
poo_storm = 63322
poop = 63001
portrait = 62432
pound_sign = 61780
power_off = 61457
pray = 63107
praying_hands = 63108
prescription = 62897
prescription_bottle = 62597
prescription_bottle_alt = 62598
print = 61487
procedures = 62599
project_diagram = 62786
pump_medical = 57450
pump_soap = 57451
puzzle_piece = 61742
qrcode = 61481
question = 61736
question_circle = 61529
quidditch = 62552
quote_left = 61709
quote_right = 61710
quran = 63111
radiation = 63417
radiation_alt = 63418
rainbow = 63323
random = 61556
receipt = 62787
record_vinyl = 63705
recycle = 61880
redo = 61470
redo_alt = 62201
registered = 62045
remove_format = 63613
reply = 62437
reply_all = 61730
republican = 63326
restroom = 63421
retweet = 61561
ribbon = 62678
ring = 63243
road = 61464
robot = 62788
rocket = 61749
route = 62679
rss = 61598
rss_square = 61763
ruble_sign = 61784
ruler = 62789
ruler_combined = 62790
ruler_horizontal = 62791
ruler_vertical = 62792
running = 63244
rupee_sign = 61782
sad_cry = 62899
sad_tear = 62900
satellite = 63423
satellite_dish = 63424
save = 61639
school = 62793
screwdriver = 62794
scroll = 63246
sd_card = 63426
search = 61442
search_dollar = 63112
search_location = 63113
search_minus = 61456
search_plus = 61454
seedling = 62680
server = 62003
shapes = 63007
share = 61540
share_alt = 61920
share_alt_square = 61921
share_square = 61773
shekel_sign = 61963
shield_alt = 62445
shield_virus = 57452
ship = 61978
shipping_fast = 62603
shoe_prints = 62795
shopping_bag = 62096
shopping_basket = 62097
shopping_cart = 61562
shower = 62156
shuttle_van = 62902
sign = 62681
sign_in_alt = 62198
sign_language = 62119
sign_out_alt = 62197
signal = 61458
signature = 62903
sim_card = 63428
sink = 57453
sitemap = 61672
skating = 63429
skiing = 63433
skiing_nordic = 63434
skull = 62796
skull_crossbones = 63252
slash = 63253
sleigh = 63436
sliders_h = 61918
smile = 61720
smile_beam = 62904
smile_wink = 62682
smog = 63327
smoking = 62605
smoking_ban = 62797
sms = 63437
snowboarding = 63438
snowflake = 62172
snowman = 63440
snowplow = 63442
soap = 57454
socks = 63126
solar_panel = 62906
sort = 61660
sort_alpha_down = 61789
sort_alpha_down_alt = 63617
sort_alpha_up = 61790
sort_alpha_up_alt = 63618
sort_amount_down = 61792
sort_amount_down_alt = 63620
sort_amount_up = 61793
sort_amount_up_alt = 63621
sort_down = 61661
sort_numeric_down = 61794
sort_numeric_down_alt = 63622
sort_numeric_up = 61795
sort_numeric_up_alt = 63623
sort_up = 61662
spa = 62907
space_shuttle = 61847
spell_check = 63633
spider = 63255
spinner = 61712
splotch = 62908
spray_can = 62909
square = 61640
square_full = 62556
square_root_alt = 63128
stamp = 62911
star = 61445
star_and_crescent = 63129
star_half = 61577
star_half_alt = 62912
star_of_david = 63130
star_of_life = 63009
step_backward = 61512
step_forward = 61521
stethoscope = 61681
sticky_note = 62025
stop = 61517
stop_circle = 62093
stopwatch = 62194
stopwatch_20 = 57455
store = 62798
store_alt = 62799
store_alt_slash = 57456
store_slash = 57457
stream = 62800
street_view = 61981
strikethrough = 61644
stroopwafel = 62801
subscript = 61740
subway = 62009
suitcase = 61682
suitcase_rolling = 62913
sun = 61829
superscript = 61739
surprise = 62914
swatchbook = 62915
swimmer = 62916
swimming_pool = 62917
synagogue = 63131
sync = 61473
sync_alt = 62193
syringe = 62606
table = 61646
table_tennis = 62557
tablet = 61706
tablet_alt = 62458
tablets = 62608
tachometer_alt = 62461
tag = 61483
tags = 61484
tape = 62683
tasks = 61614
taxi = 61882
teeth = 63022
teeth_open = 63023
temperature_high = 63337
temperature_low = 63339
tenge = 63447
terminal = 61728
text_height = 61492
text_width = 61493
th = 61450
th_large = 61449
th_list = 61451
theater_masks = 63024
thermometer = 62609
thermometer_empty = 62155
thermometer_full = 62151
thermometer_half = 62153
thermometer_quarter = 62154
thermometer_three_quarters = 62152
thumbs_down = 61797
thumbs_up = 61796
thumbtack = 61581
ticket_alt = 62463
times = 61453
times_circle = 61527
tint = 61507
tint_slash = 62919
tired = 62920
toggle_off = 61956
toggle_on = 61957
toilet = 63448
toilet_paper = 63262
toilet_paper_slash = 57458
toolbox = 62802
tools = 63449
tooth = 62921
torah = 63136
torii_gate = 63137
tractor = 63266
trademark = 62044
traffic_light = 63031
trailer = 57409
train = 62008
tram = 63450
transgender = 61988
transgender_alt = 61989
trash = 61944
trash_alt = 62189
trash_restore = 63529
trash_restore_alt = 63530
tree = 61883
trophy = 61585
truck = 61649
truck_loading = 62686
truck_monster = 63035
truck_moving = 62687
truck_pickup = 63036
tshirt = 62803
tty = 61924
tv = 62060
umbrella = 61673
umbrella_beach = 62922
underline = 61645
undo = 61666
undo_alt = 62186
universal_access = 62106
university = 61852
unlink = 61735
unlock = 61596
unlock_alt = 61758
upload = 61587
user = 61447
user_alt = 62470
user_alt_slash = 62714
user_astronaut = 62715
user_check = 62716
user_circle = 62141
user_clock = 62717
user_cog = 62718
user_edit = 62719
user_friends = 62720
user_graduate = 62721
user_injured = 63272
user_lock = 62722
user_md = 61680
user_minus = 62723
user_ninja = 62724
user_nurse = 63535
user_plus = 62004
user_secret = 61979
user_shield = 62725
user_slash = 62726
user_tag = 62727
user_tie = 62728
user_times = 62005
users = 61632
users_cog = 62729
users_slash = 57459
utensil_spoon = 62181
utensils = 62183
vector_square = 62923
venus = 61985
venus_double = 61990
venus_mars = 61992
vest = 57477
vest_patches = 57478
vial = 62610
vials = 62611
video = 61501
video_slash = 62690
vihara = 63143
virus = 57460
virus_slash = 57461
viruses = 57462
voicemail = 63639
volleyball_ball = 62559
volume_down = 61479
volume_mute = 63145
volume_off = 61478
volume_up = 61480
vote_yea = 63346
vr_cardboard = 63273
walking = 62804
wallet = 62805
warehouse = 62612
water = 63347
wave_square = 63550
weight = 62614
weight_hanging = 62925
wheelchair = 61843
wifi = 61931
wind = 63278
window_close = 62480
window_maximize = 62160
window_minimize = 62161
window_restore = 62162
wine_bottle = 63279
wine_glass = 62691
wine_glass_alt = 62926
won_sign = 61785
wrench = 61613
x_ray = 62615
yen_sign = 61783
yin_yang = 63149
